@@ -1,9 +1,11 @@
 # Open in their package.
 
-warn qq/Deprecated "require 'cacheout.pl'" called in $0.\n/,
-     qq/You should 'use FileCache' instead; continuing...\n" if $^W;
+if ($^W) {
+use DEPRECATE ();
+&Deprecate::DEPRECATE("FileCache");
+}
 
-use FileCache;
+use FileCache ();
 
 *cacheout = *FileCache::cacheout;
 
