@@ -1,8 +1,11 @@
 ;#
 ;#      @(#)complete.pl,v1.1            (me@anywhere.EBay.Sun.COM) 09/23/91
 ;#
-warn(qq/Deprecated "require 'complete.pl'" called from $0.\nYou should /,
-     qq/'use Term::Complete' instead; continuing\n/) if $^W;
+
+if ($^W) {
+use DEPRECATE ();
+&Deprecate::DEPRECATE("Term::Complete");
+}
 
 use Term::Complete ();
 
